@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2013 by the gtk2-perl team (see the file AUTHORS for
+# Copyright (C) 2003-2010 by the gtk2-perl team (see the file AUTHORS for
 # the full list)
 #
 # This library is free software; you can redistribute it and/or modify it under
@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU Library General Public License
 # along with this library; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
 # $Id$
 #
@@ -27,19 +27,18 @@ use Exporter;
 require DynaLoader;
 our @ISA = qw(DynaLoader Exporter);
 
-our $VERSION = '1.3293';
-
 use constant {
 	TRUE  => 1,
 	FALSE => !1, # can't use !TRUE at this point
-	SOURCE_CONTINUE => 1,
-	SOURCE_REMOVE   => !1,
 	G_PRIORITY_HIGH         => -100,
 	G_PRIORITY_DEFAULT      =>  0,
 	G_PRIORITY_HIGH_IDLE    =>  100,
 	G_PRIORITY_DEFAULT_IDLE =>  200,
 	G_PRIORITY_LOW	        =>  300,
 	G_PARAM_READWRITE       => [qw/readable writable/],
+
+	SOURCE_CONTINUE         => 1,
+	SOURCE_REMOVE           => !1,
 };
 
 # export nothing by default.
@@ -48,8 +47,6 @@ our %EXPORT_TAGS = (
 	constants => [qw/
 			TRUE
 			FALSE
-			SOURCE_CONTINUE
-			SOURCE_REMOVE
 			G_PRIORITY_HIGH
 			G_PRIORITY_DEFAULT
 			G_PRIORITY_HIGH_IDLE
@@ -69,6 +66,8 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
+our $VERSION = '1.241';
+
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
 Glib->bootstrap ($VERSION);
@@ -100,12 +99,6 @@ sub domain { $_[0]->{domain} }
 sub value { $_[0]->{value} }
 sub code { $_[0]->{code} }
 
-package Glib::Bytes;
-
-use overload
-   '""' => sub { $_[0]->get_data },
-   fallback => 1;
-
 package Glib::Object::Property;
 
 use Carp;
@@ -222,155 +215,6 @@ sub AUTOLOAD {
 	return $object_or_type->$method (@_);
 }
 
-package Glib::Variant;
-
-my %LEAF_HANDLERS = (
-  b => ['new_boolean', 'get_boolean'],
-  y => ['new_byte', 'get_byte'],
-  n => ['new_int16', 'get_int16'],
-  q => ['new_uint16', 'get_uint16'],
-  i => ['new_int32', 'get_int32'],
-  u => ['new_uint32', 'get_uint32'],
-  x => ['new_int64', 'get_int64'],
-  t => ['new_uint64', 'get_uint64'],
-  h => ['new_handle', 'get_handle'],
-  d => ['new_double', 'get_double'],
-  s => ['new_string', 'get_string'],
-  o => ['new_object_path', 'get_string'],
-  g => ['new_signature', 'get_string'],
-);
-
-# Documented in GVariant.xs.
-sub new {
-  my ($class, $format, @values) = @_;
-  if (!defined $format || $format eq '') {
-    return;
-  }
-
-  my ($ts, $format_rest) = Glib::VariantType::string_scan ($format);
-  my ($value, @values_rest) = @values;
-  my $t = Glib::VariantType->new ($ts);
-  my $v;
-
-  if ($t->is_basic) {
-    my $ctor = $LEAF_HANDLERS{$t->get_string}->[0];
-    $v = Glib::Variant->$ctor ($value);
-  }
-
-  elsif ($t->is_variant) {
-    $v = Glib::Variant->new_variant ($value);
-  }
-
-  elsif ($t->is_array) {
-    my $et = $t->element;
-    my @children;
-    if (eval { defined $#$value }) {
-      @children = map { Glib::Variant->new ($et->get_string, $_) } @$value;
-    } elsif ($et->is_dict_entry && eval { defined scalar %$value }) {
-      while (my ($ek, $ev) = each %$value) {
-        push @children, Glib::Variant->new ($et->get_string, [$ek, $ev]);
-      }
-    } else {
-      Carp::croak ('Expected an array ref');
-    }
-    $v = Glib::Variant->new_array ($et, \@children);
-  }
-
-  elsif ($t->is_maybe) {
-    my $et = $t->element;
-    my $child = defined $value ? Glib::Variant->new ($et->get_string, $value) : undef;
-    $v = Glib::Variant->new_maybe ($et, $child);
-  }
-
-  elsif ($t->is_tuple) {
-    my $n = $t->n_items;
-    if ($n && !eval { $#$value+1 == $n }) {
-      Carp::croak ("Expected an array ref with $n elements");
-    }
-    my @children;
-    for (my ($i, $et) = (0, $t->first); $et; $i++, $et = $et->next) {
-      push @children, Glib::Variant->new ($et->get_string, $value->[$i]);
-    }
-    $v = Glib::Variant->new_tuple (\@children);
-  }
-
-  elsif ($t->is_dict_entry) {
-    my $kt = $t->first;
-    my $vt = $kt->next;
-    my $kv = Glib::Variant->new ($kt->get_string, $value->[0]);
-    my $vv = Glib::Variant->new ($vt->get_string, $value->[1]);
-    $v = Glib::Variant->new_dict_entry ($kv, $vv);
-  }
-
-  else {
-    Carp::croak ("Cannot handle the part '$ts' in the format string '$format'");
-  }
-
-  return wantarray ? ($v, Glib::Variant->new ($format_rest, @values_rest)) : $v;
-}
-
-# Documented in GVariant.xs.
-sub get {
-  my ($v, $format) = @_;
-  if (!defined $format || $format eq '') {
-    return;
-  }
-
-  my ($ts, $format_rest) = Glib::VariantType::string_scan ($format);
-  if (defined $format_rest) {
-    Carp::carp ("Unhandled rest of format string detected: '$format_rest'");
-  }
-  my $t = Glib::VariantType->new ($ts);
-  my $value;
-
-  if ($t->is_basic) {
-    my $getter = $LEAF_HANDLERS{$t->get_string}->[1];
-    $value = $v->$getter;
-  }
-
-  elsif ($t->is_variant) {
-    $value = $v->get_variant;
-  }
-
-  elsif ($t->is_array) {
-    my $et = $t->element;
-    my @children;
-    foreach my $i (1 .. $v->n_children) {
-      push @children, $v->get_child_value ($i-1)->get ($et->get_string);
-    }
-    $value = \@children;
-  }
-
-  elsif ($t->is_maybe) {
-    my $et = $t->element;
-    my $wrapper = $v->get_maybe;
-    $value = defined $wrapper ? $wrapper->get ($et->get_string) : undef;
-  }
-
-  elsif ($t->is_tuple) {
-    my $n = $t->n_items;
-    my @children;
-    for (my ($i, $et) = (0, $t->first); $et; $i++, $et = $et->next) {
-      push @children, $v->get_child_value ($i)->get ($et->get_string);
-    }
-    $value = \@children;
-  }
-
-  elsif ($t->is_dict_entry) {
-    my $kt = $t->first;
-    my $vt = $kt->next;
-    my $kv = $v->get_child_value (0)->get ($kt->get_string);
-    my $vv = $v->get_child_value (1)->get ($vt->get_string);
-    $value = [$kv, $vv];
-  }
-
-  else {
-    Carp::croak ("Cannot handle the part '$ts' in the format string '$format'");
-  }
-
-  return $value;
-}
-
 package Glib;
 
 1;
@@ -749,8 +593,6 @@ you can also get all of them with the export tag "all".
 
   TRUE
   FALSE
-  SOURCE_CONTINUE
-  SOURCE_REMOVE
   G_PRIORITY_HIGH
   G_PRIORITY_DEFAULT
   G_PRIORITY_HIGH_IDLE
